Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'build_files/cmake/cmake_netbeans_project.py')
-rwxr-xr-xbuild_files/cmake/cmake_netbeans_project.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/build_files/cmake/cmake_netbeans_project.py b/build_files/cmake/cmake_netbeans_project.py
index b2b1f062509..fc6c64db1cd 100755
--- a/build_files/cmake/cmake_netbeans_project.py
+++ b/build_files/cmake/cmake_netbeans_project.py
@@ -24,7 +24,7 @@
"""
Example linux usage
- python3 ~/blenderSVN/blender/build_files/cmake/cmake_netbeans_project.py ~/blenderSVN/cmake
+ python3 ~/blender-git/blender/build_files/cmake/cmake_netbeans_project.py ~/blender-git/cmake
Windows not supported so far
"""
@@ -67,7 +67,7 @@ def create_nb_project_main():
if 0:
PROJECT_NAME = "Blender"
else:
# be tricky, get the project name from SVN if we can!
PROJECT_NAME = project_name_get()
# --------------- NB spesific
@@ -67,7 +67,7 @@ def create_nb_project_main():
PROJECT_NAME = "Blender"
else:
- # be tricky, get the project name from SVN if we can!
+ # be tricky, get the project name from git if we can!
PROJECT_NAME = project_name_get()
# --------------- NB spesific